Struct tls_parser::DTLSPlaintext [−][src]
pub struct DTLSPlaintext<'a> {
pub header: DTLSRecordHeader,
pub messages: Vec<DTLSMessage<'a>>,
}Expand description
DTLS Plaintext record
Each DTLS record MUST fit within a single datagram.
Multiple DTLS records may be placed in a single datagram.
Fields
header: DTLSRecordHeadermessages: Vec<DTLSMessage<'a>>Trait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.