Struct tls_parser::DTLSRecordHeader [−][src]
pub struct DTLSRecordHeader {
pub content_type: TlsRecordType,
pub version: TlsVersion,
pub epoch: u16,
pub sequence_number: u64,
pub length: u16,
}Expand description
DTLS Plaintext record header
Fields
content_type: TlsRecordTypeversion: TlsVersionepoch: u16A counter value that is incremented on every cipher state change.
sequence_number: u64The sequence number for this record.
length: u16Trait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.