Struct tls_parser::ExplicitPrimeContent [−][src]
pub struct ExplicitPrimeContent<'a> {
pub prime_p: &'a [u8],
pub curve: ECCurve<'a>,
pub base: ECPoint<'a>,
pub order: &'a [u8],
pub cofactor: &'a [u8],
}Expand description
Elliptic curve parameters, conveyed verbosely as a prime field, as defined in RFC4492 section 5.4
Fields
prime_p: &'a [u8]curve: ECCurve<'a>base: ECPoint<'a>order: &'a [u8]cofactor: &'a [u8]Trait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.