Struct tls_parser::TlsCertificateContents [−][src]
pub struct TlsCertificateContents<'a> {
pub cert_chain: Vec<RawCertificate<'a>>,
}Expand description
The certificate chain, usually composed of the certificate, and all required certificate authorities.
Fields
cert_chain: Vec<RawCertificate<'a>>Trait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.