Struct tls_parser::TlsMessageApplicationData [−][src]
TLS application data
Since this message can only be sent after the handshake, data is stored as opaque.
Fields
blob: &'a [u8]Trait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.