Struct tls_parser::TlsMessageHeartbeat [−][src]
pub struct TlsMessageHeartbeat<'a> {
pub heartbeat_type: TlsHeartbeatMessageType,
pub payload_len: u16,
pub payload: &'a [u8],
}Expand description
TLS heartbeat message, as defined in RFC6520
Heartbeat messages should not be sent during handshake, but in practise they can (and this caused heartbleed).
Fields
heartbeat_type: TlsHeartbeatMessageTypepayload_len: u16payload: &'a [u8]Trait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.