Struct tls_parser::TlsPlaintext [−][src]
pub struct TlsPlaintext<'a> {
pub hdr: TlsRecordHeader,
pub msg: Vec<TlsMessage<'a>>,
}Expand description
TLS plaintext record
A TLS record can contain multiple messages (sharing the same record type). Plaintext records can only be found during the handshake.
Fields
hdr: TlsRecordHeadermsg: Vec<TlsMessage<'a>>Trait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.