[−][src]Struct tls_parser::tls::TlsEncrypted
Encrypted TLS record (containing opaque data)
Fields
hdr: TlsRecordHeadermsg: TlsEncryptedContent<'a>Trait Implementations
impl<'a> PartialEq<TlsEncrypted<'a>> for TlsEncrypted<'a>[src]
impl<'a> PartialEq<TlsEncrypted<'a>> for TlsEncrypted<'a>fn eq(&self, other: &TlsEncrypted<'a>) -> bool | [src] |
fn ne(&self, other: &TlsEncrypted<'a>) -> bool | [src] |
impl<'a> Clone for TlsEncrypted<'a>[src]
impl<'a> Clone for TlsEncrypted<'a>fn clone(&self) -> TlsEncrypted<'a> | [src] |
fn clone_from(&mut self, source: &Self) | 1.0.0 [src] |
Performs copy-assignment from source. Read more
impl<'a> Debug for TlsEncrypted<'a>[src]
impl<'a> Debug for TlsEncrypted<'a>Auto Trait Implementations
impl<'a> Send for TlsEncrypted<'a>
impl<'a> Send for TlsEncrypted<'a>impl<'a> Sync for TlsEncrypted<'a>
impl<'a> Sync for TlsEncrypted<'a>Blanket Implementations
impl<T> From for T[src]
impl<T> From for Timpl<T, U> Into for T where
U: From<T>, [src]
impl<T, U> Into for T where
U: From<T>, impl<T> ToOwned for T where
T: Clone, [src]
impl<T> ToOwned for T where
T: Clone, impl<T, U> TryFrom for T where
T: From<U>, [src]
impl<T, U> TryFrom for T where
T: From<U>, type Error = !
🔬 This is a nightly-only experimental API. (
try_from)The type returned in the event of a conversion error.
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error> | [src] |
impl<T> Borrow for T where
T: ?Sized, [src]
impl<T> Borrow for T where
T: ?Sized, impl<T> BorrowMut for T where
T: ?Sized, [src]
impl<T> BorrowMut for T where
T: ?Sized, fn borrow_mut(&mut self) -> &mut T | [src] |
impl<T, U> TryInto for T where
U: TryFrom<T>, [src]
impl<T, U> TryInto for T where
U: TryFrom<T>, type Error = <U as TryFrom<T>>::Error
🔬 This is a nightly-only experimental API. (
try_from)The type returned in the event of a conversion error.
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error> | [src] |
impl<T> Any for T where
T: 'static + ?Sized, [src]
impl<T> Any for T where
T: 'static + ?Sized, fn get_type_id(&self) -> TypeId | [src] |