[][src]Struct tls_parser::tls::TlsVersion

pub struct TlsVersion(pub u16);

TLS version

Only the TLS version defined in the TLS message header is meaningful, the version defined in the record should be ignored or set to TLS 1.0

Methods

impl TlsVersion