[−][src]Struct tls_parser::tls_ec::ECParameters
Elliptic curve parameters, defined in RFC4492 section 5.4
Fields
curve_type: ECCurveTypeShould match a ECCurveType value
params_content: ECParametersContent<'a>Trait Implementations
impl<'a> PartialEq<ECParameters<'a>> for ECParameters<'a>[src]
impl<'a> PartialEq<ECParameters<'a>> for ECParameters<'a>fn eq(&self, other: &ECParameters<'a>) -> bool | [src] |
fn ne(&self, other: &ECParameters<'a>) -> bool | [src] |
impl<'a> Debug for ECParameters<'a>[src]
impl<'a> Debug for ECParameters<'a>Auto Trait Implementations
impl<'a> Send for ECParameters<'a>
impl<'a> Send for ECParameters<'a>impl<'a> Sync for ECParameters<'a>
impl<'a> Sync for ECParameters<'a>Blanket Implementations
impl<T> From for T[src]
impl<T> From for Timpl<T, U> Into for T where
U: From<T>, [src]
impl<T, U> Into for T where
U: From<T>, impl<T, U> TryFrom for T where
T: From<U>, [src]
impl<T, U> TryFrom for T where
T: From<U>, type Error = !
🔬 This is a nightly-only experimental API. (
try_from)The type returned in the event of a conversion error.
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error> | [src] |
impl<T> Borrow for T where
T: ?Sized, [src]
impl<T> Borrow for T where
T: ?Sized, impl<T> BorrowMut for T where
T: ?Sized, [src]
impl<T> BorrowMut for T where
T: ?Sized, fn borrow_mut(&mut self) -> &mut T | [src] |
impl<T, U> TryInto for T where
U: TryFrom<T>, [src]
impl<T, U> TryInto for T where
U: TryFrom<T>, type Error = <U as TryFrom<T>>::Error
🔬 This is a nightly-only experimental API. (
try_from)The type returned in the event of a conversion error.
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error> | [src] |
impl<T> Any for T where
T: 'static + ?Sized, [src]
impl<T> Any for T where
T: 'static + ?Sized, fn get_type_id(&self) -> TypeId | [src] |