pub enum TlsExtension<'a> {
SNI(Vec<(SNIType, &'a [u8])>),
MaxFragmentLength(u8),
StatusRequest(Option<(CertificateStatusType, &'a [u8])>),
EllipticCurves(Vec<NamedGroup>),
EcPointFormats(&'a [u8]),
SignatureAlgorithms(Vec<u16>),
SessionTicket(&'a [u8]),
KeyShareOld(&'a [u8]),
KeyShare(&'a [u8]),
PreSharedKey(&'a [u8]),
EarlyData(Option<u32>),
SupportedVersions(Vec<TlsVersion>),
Cookie(&'a [u8]),
PskExchangeModes(Vec<u8>),
Heartbeat(u8),
ALPN(Vec<&'a [u8]>),
SignedCertificateTimestamp(Option<&'a [u8]>),
Padding(&'a [u8]),
EncryptThenMac,
ExtendedMasterSecret,
OidFilters(Vec<OidFilter<'a>>),
PostHandshakeAuth,
NextProtocolNegotiation,
RenegotiationInfo(&'a [u8]),
Grease(u16, &'a [u8]),
Unknown(TlsExtensionType, &'a [u8]),
}
PostHandshakeAuthThis method tests for self and other values to be equal, and is used by ==. Read more
This method tests for !=.
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static