[−][src]Struct tls_parser::tls::TlsVersion
TLS version
Only the TLS version defined in the TLS message header is meaningful, the version defined in the record should be ignored or set to TLS 1.0
Methods
impl TlsVersion
impl TlsVersionpub const Ssl30: TlsVersion
pub const Tls10: TlsVersion
pub const Tls11: TlsVersion
pub const Tls12: TlsVersion
pub const Tls13: TlsVersion
pub const Tls13Draft18: TlsVersion
pub const Tls13Draft19: TlsVersion
pub const Tls13Draft20: TlsVersion
pub const Tls13Draft21: TlsVersion
pub const Tls13Draft22: TlsVersion
pub const Tls13Draft23: TlsVersion